@@ -10,8 +10,14 @@
 #undef MP2ENC_LOCATION
 #undef MPEG2ENC_LOCATION
 #undef YUVSCALER_LOCATION
+#undef YUVDENOISE_LOCATION
 #undef MPLEX_LOCATION
 #undef LAVTRANS_LOCATION
+#undef YUVPLAY_LOCATION
+#undef YUV2LAV_LOCATION
+#undef LAVPIPE_LOCATION
+#undef LAVADDWAV_LOCATION
+#undef YUV2DIVX_LOCATION
 
 /* mixer, video and audio devices */
 #undef DEFAULT_MIXER
@@ -22,5 +28,9 @@
 #undef OSS
 #undef ALSA
 
-/* The maximum number of scenes that the editor can open */
-#undef MAX_NUM_SCENES
+/* Have lirc? */
+#undef HAVE_LIRC
+
+/* png/jpeg support */
+#undef HAVE_JPEG
+#undef HAVE_PNG
