@@ -140,6 +140,7 @@ static void gtk_enhanced_scale_init (GtkEnhancedScale *enhanced_scale)
 	enhanced_scale->active_slider = 0; /* default */
 	enhanced_scale->clicked_slider = -1; /* none */
 	enhanced_scale->x_click_point = 0;
+	enhanced_scale->all_the_same = 0; /* first one should be different */
 
 	GTK_WIDGET_SET_FLAGS (GTK_WIDGET(enhanced_scale), GTK_CAN_FOCUS);
 }
@@ -246,6 +247,10 @@ static void gtk_enhanced_scale_realize (GtkWidget *widget)
 #endif
 	enhanced_scale->trough = gdk_window_new (widget->window, &attributes, attributes_mask);
 
+	if (enhanced_scale->all_the_same)
+		ENHANCED_SCALE_CLASS (enhanced_scale)->slider_length =
+			ENHANCED_SCALE_CLASS (enhanced_scale)->arrow_width;
+
 	attributes.width = ENHANCED_SCALE_CLASS (enhanced_scale)->slider_length;
 	attributes.height = slider_width;
 	attributes.event_mask |= (GDK_BUTTON_MOTION_MASK |
@@ -461,7 +466,7 @@ static void gtk_enhanced_scale_draw_slider (GtkEnhancedScale *enhanced_scale, gi
 		else
 			state_type = GTK_STATE_NORMAL;
 
-		if(i==0)
+		if(i==0 && enhanced_scale->all_the_same==0)
 			gtk_paint_slider (GTK_WIDGET (enhanced_scale)->style, enhanced_scale->slider[i],
 				state_type, GTK_SHADOW_OUT, NULL, GTK_WIDGET (enhanced_scale), "hscale",
 				0, 0, -1, -1, GTK_ORIENTATION_HORIZONTAL); 
