@@ -8,7 +8,9 @@
 #define STUDIO_ERROR 1
 #define STUDIO_INFO 2
 
-void gtk_show_text_window(int type, char *message, char *message2);
+void gtk_show_text_window(int type, char *format, ...);
 GtkWidget *gtk_widget_from_xpm_data(gchar **data);
+void set_background_color(GtkWidget *widget, int r, int g, int b);
+GtkWidget *gtk_image_label_button(char *label, char *tooltip, gchar **imagedata, gint spacing, GtkPositionType pos);
 
 #endif /* __GTK_FUNCTIONS_H__ */
