@@ -153,7 +153,7 @@ void quit_lavplay_with_error(char *msg)
 	quit_lavplay();
 	if (verbose) g_print("Lavplay error: %s\n", msg);
 	gtk_show_text_window(STUDIO_ERROR,
-		"Lavplay stopped and gave the following error:",
+		"Lavplay stopped and gave the following error: %s",
 		msg);
 }
 
@@ -163,7 +163,18 @@ void process_lavplay_input(char *msg)
 
 	if(msg[0]=='@')
 	{
-		sscanf(msg+1,"%c%d/%d/%d",&lavplay_norm,&cur_pos,&total_frames,&cur_speed);
+		int n, tot=0;
+		for (n=0;msg[n];n++)
+			if (msg[n]=='/')
+				tot++;
+		if (tot==2)
+			sscanf(msg+1,"%c%d/%d/%d",&lavplay_norm,&cur_pos,&total_frames,&cur_speed);
+		else
+		{
+			int norm_num;
+			sscanf(msg+1,"%d/%d/%d/%d",&norm_num,&cur_pos,&total_frames,&cur_speed);
+			lavplay_norm = (norm_num==25)?'p':'n';
+		}
 		set_lavplay_log(lavplay_norm, cur_pos, cur_speed);
 		return;
 	}
@@ -174,42 +185,50 @@ void process_lavplay_input(char *msg)
 		quit_lavplay_with_error(msg+9);
 	}
 
-	if(strncmp(msg, "--DEBUG:    ", 12) == 0)
+	if(strncmp(msg, "--DEBUG:", 8) == 0)
 	{
-		if (strncmp(msg+12, "frames: ", 8)==0)
+		/* trim the strim */
+		while (msg[0]!=':' && msg[0]!='\0') msg++;
+		if (msg[2]=='[') while (msg[0]!=']' && msg[0]!='\0') msg++;
+		if (msg[0]!='\0') msg++; /* get past the ':' or ']' */
+		while (msg[0]==' ') msg++;
+
+		if (strncmp(msg, "frames: ", 8)==0)
 		{
-			sscanf(msg+12,"frames: %d",&total_frames);
+			sscanf(msg,"frames: %d",&total_frames);
 		}
-		else if (strncmp(msg+12, "width: ", 7)==0)
+		else if (strncmp(msg, "width: ", 7)==0)
 		{
-			sscanf(msg+12,"width: %d",&lavplay_sizew);
+			sscanf(msg,"width: %d",&lavplay_sizew);
 		}
-		else if (strncmp(msg+12, "height: ", 8)==0)
+		else if (strncmp(msg, "height: ", 8)==0)
 		{
-			sscanf(msg+12,"height: %d",&lavplay_sizeh);
+			sscanf(msg,"height: %d",&lavplay_sizeh);
 		}
-		else if (strncmp(msg+12, "frames/sec: ", 12)==0)
+		else if (strncmp(msg, "frames/sec: ", 12)==0)
 		{
-			sscanf(msg+12,"frames/sec: %d",&lavplay_fps);
+			sscanf(msg,"frames/sec: %d",&lavplay_fps);
 		}
-		else if (strncmp(msg+12, "audio chans: ", 13)==0)
+		else if (strncmp(msg, "audio chans: ", 13)==0)
 		{
-			sscanf(msg+12,"audio chans: %d",&lavplay_chans);
+			sscanf(msg,"audio chans: %d",&lavplay_chans);
 		}
-		else if (strncmp(msg+12, "audio bits: ", 12)==0)
+		else if (strncmp(msg, "audio bits: ", 12)==0)
 		{
-			sscanf(msg+12,"audio bits: %d",&lavplay_absize);
+			sscanf(msg,"audio bits: %d",&lavplay_absize);
 		}
-		else if (strncmp(msg+12, "audio rate: ", 12)==0)
+		else if (strncmp(msg, "audio rate: ", 12)==0)
 		{
-			sscanf(msg+12,"audio rate: %d",&lavplay_abrate);
+			sscanf(msg,"audio rate: %d",&lavplay_abrate);
 		}
 		return;
 	}
 
-	if (strncmp(msg, "   INFO: Output norm: ",22) == 0)
+	if ((msg=strstr(msg, "Output norm: "))!=NULL)
 	{
-		if (msg[23] == 'N')
+		char norm;
+		sscanf(msg, "Output norm: %c", &norm);
+		if (norm == 'N')
 			lavplay_norm = 'n';
 		else
 			lavplay_norm = 'p';
@@ -217,32 +236,6 @@ void process_lavplay_input(char *msg)
 	}
 }
 
-/*void lavplay_input(gpointer data, gint source, GdkInputCondition condition)
-{
-	char input[4096];
-	int i, n;
-	static char inpbuff[4096];
-	static int inplen = 0;
-
-	n = read(source,input,4095);
-	if(n==0)
-	{
-		printf("No child input\n");;
-		quit_lavplay();
-	}
-
-	for(i=0;i<n;i++)
-	{
-		if(inplen<4095) inpbuff[inplen++] = input[i];
-		if(input[i]=='\n')
-		{
-			inpbuff[inplen] = 0;
-			process_lavplay_input(inpbuff, inplen);
-			inplen = 0;
-		}
-	}
-}*/
-
 void quit_lavplay()
 {
 	close_pipe(LAVPLAY);
@@ -256,60 +249,15 @@ void lavplay_stopped()
 
 void create_lavplay_child()
 {
-/*	int ipipe[2], opipe[2];*/
 	char *lavplay_command[256];
 	int n;
 
-/*	if(pipe(ipipe)!=0 || pipe(opipe)!=0) { perror("Starting Lavplay"); exit(1); }
-
-	lavplay_pid = fork();
-
-	if(lavplay_pid<0) { perror("Starting Lavplay"); exit(1); }
-
-	if (lavplay_pid)
-	{
-		// We are the parent
-
-		lavplay_inp_pipe = ipipe[0];
-		close(ipipe[1]);
-		fcntl (lavplay_inp_pipe, F_SETFL, O_NONBLOCK);
-		lavplay_out_pipe = opipe[1];
-		close(opipe[0]);
-		fcntl (lavplay_out_pipe, F_SETFL, O_NONBLOCK);
-		studio_lavplay_gint = gdk_input_add (lavplay_inp_pipe, GDK_INPUT_READ, lavplay_input, NULL);
-	}
-	else
-	{
-		// We are the child
-
-		close(ipipe[0]);
-		close(opipe[1]);
-
-		close(0);
-		n = dup(opipe[0]);
-		if(n!=0) exit(1);
-		close(opipe[0]);
-		close(1);
-		n = dup(ipipe[1]);
-		if(n!=1) exit(1);
-		close(ipipe[1]);
-		close(2);
-		n = dup(1);
-		if(n!=2) exit(1);
-
-		execlp(LAVPLAY_LOCATION, LAVPLAY_LOCATION, "-q", "-g", "-v2",
-			gtk_entry_get_text(GTK_ENTRY(textfield2)), NULL);
-
-		// Kill child
-		exit(1);
-	}*/
-
 	n=0;
-	lavplay_command[n] = LAVPLAY_LOCATION; n++;
+	lavplay_command[n] = app_name(LAVPLAY); n++;
 	lavplay_command[n] = "-q"; n++;
 	lavplay_command[n] = "-g"; n++;
 	lavplay_command[n] = "-v"; n++; lavplay_command[n] = "2"; n++;
-	lavplay_command[n] = "-C"; n++;
+	lavplay_command[n] = "-pC"; n++;
 	lavplay_command[n] = gtk_entry_get_text(GTK_ENTRY(textfield2)); n++;
 	lavplay_command[n] = NULL;
 
@@ -329,7 +277,7 @@ void play_file(GtkWidget *widget, gpointer data)
 void reset_lavplay_tv()
 {
 	gtk_widget_set_usize(GTK_WIDGET(lavplay_tv), tv_width_process, tv_height_process);
-	draw_tv(GTK_WIDGET(lavplay_tv), port);
+	gtk_tvplug_set(GTK_WIDGET(lavplay_tv), "port", port);
 }
 
 void file_ok_sel2( GtkWidget *w, GtkFileSelection *fs )
@@ -445,84 +393,60 @@ void command_to_lavplay(GtkWidget *widget, gpointer data)
 
 GtkWidget *create_lavplay_buttons()
 {
-	GtkWidget *pixmap_widget, *hbox3, *button;
-	GtkTooltips *tooltip;
-
-	tooltip = gtk_tooltips_new();
+	GtkWidget *hbox3, *button;
 
 	hbox3 = gtk_hbox_new(TRUE, 5);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_fast_i_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Play Fast Backwards", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "Play Fast Backwards",
+				editor_fast_i_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"p-3");
 	gtk_box_pack_start (GTK_BOX (hbox3), button, FALSE, FALSE, 0);
 	gtk_widget_set_usize(button, 32, 32);
 	gtk_widget_show(button);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_play_i_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Play Backwards", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "Play Backwards",
+				editor_play_i_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"p-1");
 	gtk_box_pack_start (GTK_BOX (hbox3), button, FALSE, FALSE, 0);
 	gtk_widget_set_usize(button, 32, 32);
 	gtk_widget_show(button);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_step_i_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "One Frame Backwards", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "One Frame Backwards",
+				editor_step_i_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"-");
 	gtk_box_pack_start (GTK_BOX (hbox3), button, FALSE, FALSE, 0);
 	gtk_widget_set_usize(button, 32, 32);
 	gtk_widget_show(button);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_pause_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Pause", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "Pause",
+				editor_pause_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"p0");
 	gtk_box_pack_start (GTK_BOX (hbox3), button,FALSE, FALSE, 0);
 	gtk_widget_set_usize(button, 32, 32);
 	gtk_widget_show(button);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_step_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "One Frame Forward", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "One Frame Forward",
+				editor_step_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"+");
 	gtk_box_pack_start (GTK_BOX (hbox3), button, FALSE, FALSE, 0);
 	gtk_widget_set_usize(button, 32, 32);
 	gtk_widget_show(button);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_play_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Play Forward", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "Play Forward",
+				editor_play_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"p1");
 	gtk_box_pack_start (GTK_BOX (hbox3), button, FALSE, FALSE, 0);
 	gtk_widget_set_usize(button, 32, 32);
 	gtk_widget_show(button);
 
-	button = gtk_button_new();
-	pixmap_widget = gtk_widget_from_xpm_data(editor_fast_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Play Fast Forward", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL, "Play Fast Forward",
+				editor_fast_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		GTK_SIGNAL_FUNC(command_to_lavplay),"p3");
 	gtk_box_pack_start (GTK_BOX (hbox3), button, FALSE, FALSE, 0);
@@ -535,11 +459,8 @@ GtkWidget *create_lavplay_buttons()
 GtkWidget *create_lavplay_layout()
 {
 	GtkWidget *hbox2, *hbox, *vbox, *vbox2, *label, *button;
-	GtkWidget *scrollbar, *table, *pixmap_widget, *hbox3;
+	GtkWidget *scrollbar, *table, *hbox3;
 	char tempfile[100];
-	GtkTooltips *tooltip;
-
-	tooltip = gtk_tooltips_new();
 
 	vbox = gtk_vbox_new(FALSE,0);
 	vbox2 = gtk_vbox_new(FALSE,0);
@@ -554,7 +475,7 @@ GtkWidget *create_lavplay_layout()
 	gtk_widget_set_usize(GTK_WIDGET(lavplay_tv), tv_width_process, tv_height_process);
 	if (port == -1)
 		exit(1);
-	gtk_box_pack_start (GTK_BOX (vbox2), lavplay_tv,TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox2), lavplay_tv, TRUE, FALSE, 0);
 	gtk_widget_show(lavplay_tv);
 
 	lavplay_slider_adj = gtk_adjustment_new(0, 0, 2500000, 10000, 100000, 0);
@@ -575,8 +496,8 @@ GtkWidget *create_lavplay_layout()
 	vbox2 = gtk_vbox_new(FALSE, 10);
 
 	hbox2 = gtk_hbox_new(FALSE,10);
-	label = gtk_label_new("Play from:");
-	gtk_box_pack_start(GTK_BOX(hbox2), label, TRUE, TRUE, 0);
+	label = gtk_label_new("Play from: ");
+	gtk_box_pack_start(GTK_BOX(hbox2), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 	textfield2 = gtk_entry_new();
 	sprintf(tempfile, "%s/%s", getenv("HOME"), "video001.avi");
@@ -584,13 +505,11 @@ GtkWidget *create_lavplay_layout()
 	gtk_box_pack_start (GTK_BOX (hbox2), textfield2, TRUE, TRUE, 0);
 	gtk_widget_show(textfield2);
 
-	button = gtk_button_new(); //_with_label("Select");
-	pixmap_widget = gtk_widget_from_xpm_data(file_widget_open_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Open movie or editlist", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL,
+				"Open Movie or Editlist",
+				file_widget_open_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(create_filesel2), NULL);
-	gtk_box_pack_start (GTK_BOX (hbox2), button, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox2), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox2, TRUE, FALSE, 10);
 	gtk_widget_show(hbox2);
