@@ -47,6 +47,8 @@
 #include "slider_brightness.xpm"
 #include "slider_volume.xpm"
 #include "file_widget_open.xpm"
+#include "editor_record.xpm"
+#include "editor_stop.xpm"
 
 /* Variables */
 //int inp_pipe, out_pipe, pid_lr, capturing;
@@ -57,6 +59,8 @@ GtkWidget *table_label_aerrors, *table_label_inserted, *table_label_deleted, *ta
 int mixer_id;
 int current_file;
 char files_recorded[256][256];
+GtkWidget *scene_detection_window;
+char eli_file[256];
 
 GtkWidget *scene_detection_status_label, *scene_detection_button_label, *scene_detection_bar;
 
@@ -78,19 +82,27 @@ void create_filesel1(GtkWidget *widget, gpointer data);
 void write_result(GtkWidget *widget, gpointer data);
 GtkWidget *create_buttons(GtkWidget *vbox, GtkWidget *window);
 void create_lavrec_logtable(GtkWidget *table);
-GtkWidget *create_audio_sliders(GtkWidget *window);
+GtkWidget *create_audio_sliders(void);
 void audio_slider_changed(GtkAdjustment *adj, gpointer data);
-GtkWidget *create_video_sliders(GtkWidget *window);
+GtkWidget *create_video_sliders(void);
 void video_slider_changed(GtkAdjustment *adj, char *what);
 void create_scene_detection_window(void);
 void scene_detection_input_cb(char *input);
 void stop_scene_detection_process(GtkWidget *widget, gpointer data);
 void scene_detection_finished(void);
+void scene_detection_open_movie(GtkWidget *widget, gpointer data);
 
 /* ================================================================= */
 
+void scene_detection_open_movie(GtkWidget *widget, gpointer data)
+{
+	global_open_location(eli_file);
+}
+
 void scene_detection_finished()
 {
+	GtkWidget *dialog_window, *button, *vbox, *hbox, *label;
+
 	if (scene_detection_button_label)
 		gtk_label_set_text(GTK_LABEL(scene_detection_button_label),
 		" Close ");
@@ -100,53 +112,95 @@ void scene_detection_finished()
 	if (scene_detection_status_label)
 		gtk_label_set_text(GTK_LABEL(scene_detection_status_label),
 		"Scene detection finished!");
+
+	scene_detection_button_label = NULL;
+	scene_detection_status_label = NULL;
+	scene_detection_bar = NULL;
+	gtk_widget_destroy(scene_detection_window);
+
+	/* ask to open eli_file */
+	dialog_window = gtk_window_new(GTK_WINDOW_DIALOG);
+	vbox = gtk_vbox_new(FALSE, 5);
+
+	gtk_window_set_title (GTK_WINDOW(dialog_window),
+		"Linux Video Studio - Question");
+	gtk_container_set_border_width (GTK_CONTAINER (dialog_window), 20);
+
+	label = gtk_label_new("Would you like to open this movie\n" \
+		"in all the editor-subparts?");
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
+	gtk_widget_show(label);
+
+	hbox = gtk_hbox_new(TRUE, 5);
+	button = gtk_button_new_with_label("Yes");
+	gtk_signal_connect(GTK_OBJECT(button), "clicked",
+		(GtkSignalFunc)scene_detection_open_movie, NULL);
+	gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
+		gtk_widget_destroy, GTK_OBJECT(dialog_window));
+	gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+	gtk_widget_show(button);
+	button = gtk_button_new_with_label("No");
+	gtk_signal_connect_object(GTK_OBJECT(button), "clicked",
+		gtk_widget_destroy, GTK_OBJECT(dialog_window));
+	gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+	gtk_widget_show(button);
+	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	gtk_widget_show(hbox);
+
+	gtk_container_add (GTK_CONTAINER (dialog_window), vbox);
+	gtk_widget_show(vbox);
+
+	gtk_grab_add(dialog_window);
+	gtk_widget_show(dialog_window);
 }
 
 void stop_scene_detection_process(GtkWidget *widget, gpointer data)
 {
-	GtkWidget *window = (GtkWidget*)data;
-
 	close_pipe(LAV2YUV_S);
 	scene_detection_button_label = NULL;
 	scene_detection_status_label = NULL;
 	scene_detection_bar = NULL;
-	gtk_widget_destroy(window);
+	gtk_widget_destroy(scene_detection_window);
 }
 
 void scene_detection_input_cb(char *input)
 {
-	if (strncmp(input, "--DEBUG: frame", 14)==0)
+	if (strstr(input, "frame"))
 	{
 		int n1,n2,n3,n4;
-		sscanf(input, "--DEBUG: frame %d/%d, lum_mean %d, delta_lum %d",
-			&n1, &n2, &n3, &n4);
-		if (scene_detection_status_label)
-			gtk_label_set_text(GTK_LABEL(scene_detection_status_label),
-			input+9);
-		if (scene_detection_bar)
-			gtk_progress_bar_update(GTK_PROGRESS_BAR(scene_detection_bar),
-			((double)n1)/n2);
+
+		input = strstr(input, "frame");
+		if (sscanf(input, "frame %d/%d, lum_mean %d, delta_lum %d",
+			&n1, &n2, &n3, &n4) == 4)
+		{
+			if (scene_detection_status_label)
+				gtk_label_set_text(GTK_LABEL(scene_detection_status_label),
+				input);
+			if (scene_detection_bar)
+				gtk_progress_bar_update(GTK_PROGRESS_BAR(scene_detection_bar),
+					((double)n1)/n2);
+		}
 	}
 	else if (strncmp(input, "**ERROR:", 8) == 0)
 	{
 		/* error */
 		stop_scene_detection_process(NULL, NULL);
 		gtk_show_text_window(STUDIO_ERROR,
-			"Scene detection failed, lav2yuv gave the following error:",
+			"Scene detection failed, lav2yuv gave the following error: %s",
 			input+9);
 	}
 }
 
 void create_scene_detection_window()
 {
-	GtkWidget *progress_window, *vbox, *button;
+	GtkWidget *vbox, *button;
 
-	progress_window = gtk_window_new(GTK_WINDOW_DIALOG);
+	scene_detection_window = gtk_window_new(GTK_WINDOW_DIALOG);
 	vbox = gtk_vbox_new(FALSE, 5);
 
-	gtk_window_set_title (GTK_WINDOW(progress_window),
+	gtk_window_set_title (GTK_WINDOW(scene_detection_window),
 		"Linux Video Studio - Scene detection");
-	gtk_container_set_border_width (GTK_CONTAINER (progress_window), 20);
+	gtk_container_set_border_width (GTK_CONTAINER (scene_detection_window), 20);
 
 	scene_detection_status_label = gtk_label_new(" ");
 	gtk_box_pack_start (GTK_BOX (vbox), scene_detection_status_label,
@@ -166,18 +220,18 @@ void create_scene_detection_window()
 
 	button = gtk_button_new();
 	gtk_signal_connect(GTK_OBJECT(button), "clicked",
-		(GtkSignalFunc)stop_scene_detection_process, (gpointer)progress_window);
+		(GtkSignalFunc)stop_scene_detection_process, NULL);
 	scene_detection_button_label = gtk_label_new(" Cancel ");
 	gtk_container_add (GTK_CONTAINER (button), scene_detection_button_label);
 	gtk_widget_show(scene_detection_button_label);
 	gtk_box_pack_start (GTK_BOX (vbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 
-	gtk_container_add (GTK_CONTAINER (progress_window), vbox);
+	gtk_container_add (GTK_CONTAINER (scene_detection_window), vbox);
 	gtk_widget_show(vbox);
 
-	gtk_grab_add(progress_window);
-	gtk_widget_show(progress_window);
+	gtk_grab_add(scene_detection_window);
+	gtk_widget_show(scene_detection_window);
 }
 
 void do_scene_detection(GtkWidget *w, GtkFileSelection *fs)
@@ -186,7 +240,7 @@ void do_scene_detection(GtkWidget *w, GtkFileSelection *fs)
 	char temp1[256], temp2[256];
 	int n=0,i;
 
-	lav2yuv_command[n] = LAV2YUV_LOCATION; n++;
+	lav2yuv_command[n] = app_name(LAV2YUV_S); n++;
 	lav2yuv_command[n] = "-v2"; n++;
 	lav2yuv_command[n] = "-D"; n++;
 	sprintf(temp1, "%d", scene_detection_width_decimation);
@@ -195,8 +249,9 @@ void do_scene_detection(GtkWidget *w, GtkFileSelection *fs)
 	sprintf(temp2, "%d", scene_detection_treshold);
 	lav2yuv_command[n] = temp2; n++;
 	lav2yuv_command[n] = "-S"; n++;
-	lav2yuv_command[n] =
-		gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)); n++;
+	sprintf(eli_file,
+		gtk_file_selection_get_filename (GTK_FILE_SELECTION (fs)));
+	lav2yuv_command[n] = eli_file; n++;
 
 	for(i=0;i<current_file;i++)
 	{
@@ -315,21 +370,26 @@ void quit_lavrec_with_error(char *msg)
 	emulate_ctrl_c();
 	if (verbose) g_print("Lavrec error: %s\n", msg);
 	gtk_show_text_window(STUDIO_ERROR,
-		"Lavrec failed with the following error:",
+		"Lavrec failed with the following error: %s",
 		msg);
 }
 
 void dispatch_input(char *buff)
 {
 	char buff2[4096], buff3[4096];
-	int h, m, s, f, l, i, d, a;
+	int h, m, s, f, l, i, d, a, bla;
 
 	if (strcmp(buff, "Press enter to start recording>") == 0)
 	{
 		studio_set_lavrec_label("Press Start to start");
 	}
 	else if (sscanf(buff, "%d.%d.%d:%d lst: %d ins: %d del: %d ae: %d",
-		&h, &m, &s, &f, &l, &i, &d, &a)==8)
+		&h, &m, &s, &f, &l, &i, &d, &a)==8) /* 1.4.x syntax */
+	{
+		table_set_text(h, m, s, f, l, i, d, a);
+	}
+	else if (sscanf(buff, "%d.%d.%d:%d int: %d lst: %d ins: %d del: %d ae: %d",
+		&h, &m, &s, &f, &bla, &l, &i, &d, &a) == 9) /* 1.5.x syntax */
 	{
 		table_set_text(h, m, s, f, l, i, d, a);
 	}
@@ -338,62 +398,36 @@ void dispatch_input(char *buff)
 		/* Error handling */
 		quit_lavrec_with_error(buff+9);
 	}
-	else if (strncmp(buff, "   INFO: Opening output", 23) == 0)
+	else if ((buff=strstr(buff, "Opening output"))!=NULL)
 	{
-		sscanf(buff, "   INFO: Opening output file %s", buff2);
+		sscanf(buff, "Opening output file %s", buff2);
 		sprintf(buff3, "Recording to %s...\nPress \"Stop\" to stop...", buff2);
 		strcpy(files_recorded[current_file],buff2); current_file++;
 		studio_set_lavrec_label(buff3);
 	}
 }
 
-/*void lavreclog_input_cb (gpointer data, gint source, GdkInputCondition condition)
-{
-	static char inpbuff[4096];
-	static int inplen = 0;
-
-	char input[4096];
-	int i, n;
-
-	n = read(source,input,4096);
-	if(n==0) return;
-
-	for(i=0;i<n;i++)
-	{
-		if(inplen<4096-2) inpbuff[inplen++] = input[i];
-		if(input[i]=='\n' || input[i]=='\r')
-		{
-			inpbuff[inplen] = '\0';
-			dispatch_input(inpbuff, inplen);
-			inplen = 0;
-		}
-		if(input[i]=='>')
-		{
-			inpbuff[inplen] = '>';
-			inpbuff[inplen+1] = '\0';
-			dispatch_input(inpbuff, inplen+1);
-			inplen = 0;
-		}
-	}
-}*/
-
 void create_child()
 {
-	/* TODO: should actually use pipes.c calls later on */
-/*	int ipipe[2], opipe[2];*/
 	char lavrec_i[4], lavrec_f[4], lavrec_d[4], lavrec_q[6], lavrec_a[5], lavrec_r[8];
 	char lavrec_R[4], lavrec_c[4], lavrec_t[11], lavrec_T[4], lavrec_n[6], lavrec_b[8];
-	char lavrec_g[20];
+	char lavrec_g[20], lavrec_ff[6], lavrec_mfs[10];
 	int n;
 	char *lavrec_command[256];
+	char command[256];
 
 	/* create command in lavrec_command */
 	n=0;
-	lavrec_command[n] = LAVREC_LOCATION; n++;
+	lavrec_command[n] = app_name(LAVREC); n++;
 	lavrec_command[n] = "-i"; n++; sprintf(lavrec_i, "%c", input_source); lavrec_command[n] = lavrec_i; n++;
 	lavrec_command[n] = single_frame ? "-S" : "-w"; n++;
 	lavrec_command[n] = "-f"; n++; sprintf(lavrec_f, "%c", video_format); lavrec_command[n] = lavrec_f; n++;
-	lavrec_command[n] = "-d"; n++; sprintf(lavrec_d, "%i", hordcm); lavrec_command[n] = lavrec_d; n++;
+	if (!software_encoding)
+	{
+		lavrec_command[n] = "-d"; n++;
+		sprintf(lavrec_d, "%i", hordcm);
+		lavrec_command[n] = lavrec_d; n++;
+	}
 	lavrec_command[n] = "-q"; n++; sprintf(lavrec_q, "%i", quality); lavrec_command[n] = lavrec_q; n++;
 	lavrec_command[n] = "-a"; n++; sprintf(lavrec_a, "%i", audio_size); lavrec_command[n] = lavrec_a; n++;
 	lavrec_command[n] = "-r"; n++; sprintf(lavrec_r, "%i", audio_rate); lavrec_command[n] = lavrec_r; n++;
@@ -406,15 +440,43 @@ void create_child()
 	lavrec_command[n] = "-b"; n++; sprintf(lavrec_b, "%i", MJPG_bufsize); lavrec_command[n] = lavrec_b; n++;
 	if (audio_mute) { lavrec_command[n] = "-m"; n++; }
 	if (stereo) { lavrec_command[n] = "-s"; n++; }
-	if (geom_width!=0 && geom_height!=0 && geom_x!=0 && geom_y !=0)
+	if (software_encoding)
+	{ lavrec_command[n] = "--software-encoding"; n++; }
+	if (use_read)
+	{ lavrec_command[n] = "--use-read"; n++; }
+	if (file_flush > 0)
+	{
+		lavrec_command[n] = "--file_flush"; n++;
+		sprintf(lavrec_ff, "%d", file_flush);
+		lavrec_command[n] = lavrec_ff; n++;
+	}
+	if (max_file_size > 0)
+	{
+		lavrec_command[n] = "--max-file-size"; n++;
+		sprintf(lavrec_mfs, "%d", max_file_size);
+		lavrec_command[n] = lavrec_mfs; n++;
+	}
+	if ((geom_width!=0 && geom_height!=0) && !software_encoding)
 	{
 		lavrec_command[n] = "-g"; n++;
 		sprintf(lavrec_g, "%ix%i+%i+%i", geom_width, geom_height, geom_x, geom_y);
 		lavrec_command[n] = lavrec_g; n++;
 	}
+	else if (software_encoding)
+	{
+		lavrec_command[n] = "-g"; n++;
+		sprintf(lavrec_g, "%ix%i", software_recwidth, software_recheight);
+		lavrec_command[n] = lavrec_g; n++;
+	}
 	lavrec_command[n] = gtk_entry_get_text(GTK_ENTRY(textfield)); n++;
 	lavrec_command[n] = NULL;
 
+	if (verbose)
+	{
+	        command_2string(lavrec_command, command);
+		printf("Executing: %s\n",command);
+	}
+
 	start_pipe_command(lavrec_command, LAVREC);
 }
 
@@ -426,31 +488,15 @@ void emulate_enter()
 		write_pipe(LAVREC, "\n");
 		studio_set_lavrec_label("\nPress \"Stop\" to stop...");
 	}
-/*	capturing = TRUE;*/
 }
 
 void emulate_ctrl_c()
 {
-/*	if (capturing_init)
-	{
-		kill (pid_lr, SIGINT);
-		waitpid (pid_lr, NULL, 0);
-		close (inp_pipe);
-		close (out_pipe);
-		gdk_input_remove (studio_lavreclog_gint);
-		capturing = FALSE;
-		capturing_init = FALSE;
-		if (verbose) g_print("\nLavrec Stopped\n");
-		studio_set_lavrec_label("Lavrec was stopped\nPress \"Initialize Capture\" to start");
-		scene_detection();
-
-	}*/
 	close_pipe(LAVREC);
 }
 
 void lavrec_quit()
 {
-/*	capturing = FALSE;*/
 	studio_set_lavrec_label("Lavrec was stopped\nPress \"Initialize Capture\" to start");
 	scene_detection();
 }
@@ -464,7 +510,7 @@ void text_changed(GtkWidget *widget, gpointer data)
 void reset_lavrec_tv()
 {
 	gtk_widget_set_usize(GTK_WIDGET(tv), tv_width_capture, tv_height_capture);
-	draw_tv(GTK_WIDGET(tv), port);
+	gtk_tvplug_set(GTK_WIDGET(tv), "port", port);
 }
 
 void file_ok_sel1( GtkWidget *w, GtkFileSelection *fs )
@@ -491,8 +537,6 @@ void create_filesel1(GtkWidget *widget, gpointer data)
 
 void write_result(GtkWidget *widget, gpointer data)
 {
-/*	if (capturing_init)
-		emulate_ctrl_c();*/
 	if (pipe_is_active(LAVREC))
 	{
 		printf("Error, lavrec is already active!\n");
@@ -500,30 +544,23 @@ void write_result(GtkWidget *widget, gpointer data)
 	}
 	table_set_text(0, 0, 0, 0, 0, 0, 0, 0);
 	current_file = 0;
-/*	capturing_init = TRUE;*/
 	studio_set_lavrec_label("Initializing capture\nPlease wait...");
 	create_child();
 }
 
 GtkWidget *create_buttons(GtkWidget *vbox, GtkWidget *window)
 {
-	GtkWidget *hbox, *label, *button, *pixmap_widget;
-/*	GdkPixmap *pixmap;
-	GdkBitmap *mask;
-	GtkStyle *style;*/
-	GtkTooltips *tooltip;
+	GtkWidget *hbox, *label, *button;
 
-	tooltip = gtk_tooltips_new();
-/*	style = gtk_widget_get_style(window);*/
 	lavrec_label = gtk_label_new("Welcome to Linux Video Studio\nPress \"Initialize Capture\" to start");
 	gtk_box_pack_start (GTK_BOX (vbox), lavrec_label, TRUE, TRUE, 10);
 	gtk_widget_show (lavrec_label);
 
 	/*Text field where to save the file (used to be in table)*/
 	hbox = gtk_hbox_new(FALSE,10);
-	label = gtk_label_new("Capture to:");
+	label = gtk_label_new("Capture to: ");
 	gtk_misc_set_alignment(GTK_MISC(label), 0.0, GTK_MISC(label)->yalign);
-	gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show (label);
 	textfield = gtk_entry_new();
 	gtk_entry_set_text(GTK_ENTRY(textfield), record_dir);
@@ -531,39 +568,39 @@ GtkWidget *create_buttons(GtkWidget *vbox, GtkWidget *window)
 	gtk_box_pack_start (GTK_BOX (hbox), textfield, TRUE, TRUE, 0);
 	gtk_widget_show(textfield);
 
-	//button = gtk_button_new_with_label("Select");
-	button = gtk_button_new();
-/*	pixmap = gdk_pixmap_create_from_xpm_d( window->window, &mask,
-		&style->bg[GTK_STATE_NORMAL],(gchar **)file_widget_open_xpm );
-	pixmap_widget = gtk_pixmap_new(pixmap, mask);*/
-	pixmap_widget = gtk_widget_from_xpm_data(file_widget_open_xpm);
-	gtk_widget_show(pixmap_widget);
-	gtk_tooltips_set_tip(tooltip, button, "Select Recording Location", NULL);
-	gtk_container_add(GTK_CONTAINER(button), pixmap_widget);
+	button = gtk_image_label_button(NULL,
+				"Select Recording Location",
+				file_widget_open_xpm, 0, GTK_POS_BOTTOM);
 	gtk_signal_connect(GTK_OBJECT(button), "clicked", GTK_SIGNAL_FUNC(create_filesel1), NULL);
-	gtk_box_pack_start (GTK_BOX (hbox), button, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
 	gtk_widget_show(button);
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 10);
 	gtk_widget_show(hbox);
 
+	hbox = gtk_hbox_new(TRUE,25);
+
 	init_button = gtk_button_new_with_label("Initialize capture");
 	gtk_signal_connect(GTK_OBJECT(init_button), "clicked",
 		GTK_SIGNAL_FUNC(write_result), NULL);
-	gtk_box_pack_start (GTK_BOX (vbox), init_button, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), init_button, TRUE, TRUE, 0);
 	gtk_widget_show(init_button);
 
-	hbox = gtk_hbox_new(TRUE,25);
-
-	start_button = gtk_button_new_with_label("[Start]");
+	start_button = gtk_image_label_button("Start",
+				"Start Recording",
+				editor_record_xpm, 0, GTK_POS_RIGHT);
 	gtk_signal_connect(GTK_OBJECT(start_button), "clicked",
 		GTK_SIGNAL_FUNC(emulate_enter), NULL);
 	gtk_box_pack_start (GTK_BOX (hbox), start_button, TRUE, TRUE, 0);
+	gtk_widget_set_usize(start_button, -1, 32);
 	gtk_widget_show(start_button);
 
-	stop_button = gtk_button_new_with_label("[Stop]");
+	stop_button = gtk_image_label_button("Stop",
+				"Stop Recording",
+				editor_stop_xpm, 0, GTK_POS_RIGHT);
 	gtk_signal_connect(GTK_OBJECT(stop_button), "clicked",
 		GTK_SIGNAL_FUNC(emulate_ctrl_c), NULL);
 	gtk_box_pack_start (GTK_BOX (hbox), stop_button, TRUE, TRUE, 0);
+	gtk_widget_set_usize(stop_button, -1, 32);
 	gtk_widget_show(stop_button);
 
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 10);
@@ -689,18 +726,14 @@ void audio_slider_changed(GtkAdjustment *adj, gpointer data)
 	}
 }
 
-GtkWidget *create_audio_sliders(GtkWidget *window)
+GtkWidget *create_audio_sliders()
 {
 	GtkWidget *vbox, *scrollbar, *label, *pixmap_w;
 	GtkObject *adj;
-/*	GdkPixmap *pixmap;
-	GdkBitmap *mask;
-	GtkStyle *style;*/
 	GtkTooltips *tooltip;
-	int no_of_devs, i = -1, value; //, i_;
+	int no_of_devs, i = -1, value;
 
 	tooltip = gtk_tooltips_new();
-/*	style = gtk_widget_get_style(window);*/
 	vbox = gtk_vbox_new (FALSE, 0);
 
 	mixer_id = mixer_init (getenv("LAV_MIXER_DEV"));
@@ -738,9 +771,6 @@ GtkWidget *create_audio_sliders(GtkWidget *window)
 	gtk_widget_show(scrollbar);
 
 	gtk_tooltips_set_tip(tooltip, scrollbar, "Volume", NULL);
-/*	pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask,
-		&style->bg[GTK_STATE_NORMAL], slider_volume_xpm);
-	pixmap_w = gtk_pixmap_new(pixmap, mask);*/
 	pixmap_w = gtk_widget_from_xpm_data(slider_volume_xpm);
 	gtk_widget_show(pixmap_w);
 	gtk_box_pack_start(GTK_BOX(vbox), pixmap_w, FALSE, FALSE, 0);
@@ -757,127 +787,62 @@ void video_slider_changed(GtkAdjustment *adj, char *what)
 	gtk_tvplug_set(tv, what, adj->value);
 }
 
-GtkWidget *create_video_sliders(GtkWidget *window)
+GtkWidget *create_video_sliders()
 {
-	GtkWidget *hbox, *vbox, *scrollbar, *label, *pixmap_w;
-	GtkObject *adj;
-/*	GdkPixmap *pixmap;
-	GdkBitmap *mask;
-	GtkStyle *style;*/
-	GtkTooltips *tooltip;
+   GtkWidget *hbox, *vbox, *pixmap, *scrollbar;
+   GtkTooltips *tooltip;
+   int i=0;
+   char *titles[4] = {
+      "Hue",
+      "Contrast",
+      "Brightness",
+      "Colour Saturation"
+   };
+   char *names[4] = {
+      "hue",
+      "contrast",
+      "brightness",
+      "colour"
+   };
+   GtkAdjustment *adj[4] = {
+      GTK_TVPLUG(tv)->hue_adj,
+      GTK_TVPLUG(tv)->contrast_adj,
+      GTK_TVPLUG(tv)->brightness_adj,
+      GTK_TVPLUG(tv)->saturation_adj,
+   };
+   char **pixmaps[4] = {
+      slider_hue_xpm,
+      slider_contrast_xpm,
+      slider_brightness_xpm,
+      slider_sat_colour_xpm,
+   };
 
-	tooltip = gtk_tooltips_new();
-/*	style = gtk_widget_get_style(window);*/
-	hbox = gtk_hbox_new (FALSE, 20);
+   tooltip = gtk_tooltips_new();
+   hbox = gtk_hbox_new(TRUE, 20);
 
-	vbox = gtk_vbox_new (FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	adj = gtk_adjustment_new(tv!=NULL?GTK_TVPLUG(tv)->hue:0, -1000, 1000, 10, 100, 0);
-	if (tv!= NULL)
-		gtk_signal_connect(adj, "value_changed",
-			GTK_SIGNAL_FUNC(video_slider_changed), "hue");
-	scrollbar = gtk_vscale_new(GTK_ADJUSTMENT (adj));
-	gtk_scale_set_draw_value(GTK_SCALE(scrollbar), 0);
-	gtk_box_pack_start(GTK_BOX (vbox), scrollbar, TRUE, TRUE, 0);
-	gtk_widget_show(scrollbar);
-	gtk_tooltips_set_tip(tooltip, scrollbar, "Hue", NULL);
-/*	pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask, &style->bg[GTK_STATE_NORMAL], slider_hue_xpm);
-	pixmap_w = gtk_pixmap_new(pixmap, mask);*/
-	pixmap_w = gtk_widget_from_xpm_data(slider_hue_xpm);
-	gtk_widget_show(pixmap_w);
-	gtk_box_pack_start(GTK_BOX(vbox), pixmap_w, FALSE, FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	gtk_box_pack_start(GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
-	gtk_widget_show(vbox);
+   for (i=0;i<4;i++)
+   {
+      vbox = gtk_vbox_new (FALSE, 0);
+      gtk_object_ref(GTK_OBJECT(adj[i]));
+      gtk_signal_connect(GTK_OBJECT(adj[i]), "value_changed",
+         GTK_SIGNAL_FUNC(video_slider_changed), names[i]);
+      scrollbar = gtk_vscale_new(adj[i]);
+      gtk_scale_set_draw_value(GTK_SCALE(scrollbar), 0);
+      gtk_box_pack_start(GTK_BOX (vbox), scrollbar, TRUE, TRUE, 10);
+      gtk_widget_show(scrollbar);
+      gtk_widget_set_usize(scrollbar, -1, 150);
+      gtk_tooltips_set_tip(tooltip, scrollbar, titles[i], NULL);
+      pixmap = gtk_widget_from_xpm_data(pixmaps[i]);
+      gtk_widget_show(pixmap);
+      gtk_box_pack_start(GTK_BOX(vbox), pixmap, FALSE, FALSE, 10);
+      gtk_box_pack_start(GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
+      gtk_widget_show(vbox);
+   }
 
-	vbox = gtk_vbox_new (FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	adj = gtk_adjustment_new(tv!=NULL?GTK_TVPLUG(tv)->contrast:0, -1000, 1000, 10, 100, 0);
-	if (tv!=NULL)
-		gtk_signal_connect(adj, "value_changed",
-			GTK_SIGNAL_FUNC(video_slider_changed), "contrast");
-	scrollbar = gtk_vscale_new(GTK_ADJUSTMENT (adj));
-	gtk_scale_set_draw_value(GTK_SCALE(scrollbar), 0);
-	gtk_box_pack_start(GTK_BOX (vbox), scrollbar, TRUE, TRUE, 0);
-	gtk_widget_show(scrollbar);
-	gtk_tooltips_set_tip(tooltip, scrollbar, "Contrast", NULL);
-	/*label = gtk_label_new("Ctr");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);*/
-/*	pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask, &style->bg[GTK_STATE_NORMAL], slider_contrast_xpm);
-	pixmap_w = gtk_pixmap_new(pixmap, mask);*/
-	pixmap_w = gtk_widget_from_xpm_data(slider_contrast_xpm);
-	gtk_widget_show(pixmap_w);
-	gtk_box_pack_start(GTK_BOX(vbox), pixmap_w, FALSE, FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	gtk_box_pack_start(GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
-	gtk_widget_show(vbox);
-
-	vbox = gtk_vbox_new (FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	adj = gtk_adjustment_new(tv!=NULL?GTK_TVPLUG(tv)->brightness:0, -1000, 1000, 10, 100, 0);
-	if(tv!=NULL)
-		gtk_signal_connect(adj, "value_changed",
-			GTK_SIGNAL_FUNC(video_slider_changed), "brightness");
-	scrollbar = gtk_vscale_new(GTK_ADJUSTMENT (adj));
-	gtk_scale_set_draw_value(GTK_SCALE(scrollbar), 0);
-	gtk_box_pack_start(GTK_BOX (vbox), scrollbar, TRUE, TRUE, 0);
-	gtk_widget_show(scrollbar);
-	gtk_tooltips_set_tip(tooltip, scrollbar, "Brightness", NULL);
-	/*label = gtk_label_new("Brt");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);*/
-/*	pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask, &style->bg[GTK_STATE_NORMAL], slider_brightness_xpm);
-	pixmap_w = gtk_pixmap_new(pixmap, mask);*/
-	pixmap_w = gtk_widget_from_xpm_data(slider_brightness_xpm);
-	gtk_widget_show(pixmap_w);
-	gtk_box_pack_start(GTK_BOX(vbox), pixmap_w, FALSE, FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	gtk_box_pack_start(GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
-	gtk_widget_show(vbox);
-
-	vbox = gtk_vbox_new (FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	adj = gtk_adjustment_new(tv!=NULL?GTK_TVPLUG(tv)->saturation:0, -1000, 1000, 10, 100, 0);
-	if(tv!=NULL)
-		gtk_signal_connect(adj, "value_changed",
-			GTK_SIGNAL_FUNC(video_slider_changed), "colour");
-	scrollbar = gtk_vscale_new(GTK_ADJUSTMENT (adj));
-	gtk_scale_set_draw_value(GTK_SCALE(scrollbar), 0);
-	gtk_box_pack_start(GTK_BOX (vbox), scrollbar, TRUE, TRUE, 0);
-	gtk_widget_show(scrollbar);
-	gtk_tooltips_set_tip(tooltip, scrollbar, "Colour Saturation", NULL);
-	/*label = gtk_label_new("Clr");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);*/
-/*	pixmap = gdk_pixmap_create_from_xpm_d(window->window, &mask, &style->bg[GTK_STATE_NORMAL], slider_sat_colour_xpm);
-	pixmap_w = gtk_pixmap_new(pixmap, mask);*/
-	pixmap_w = gtk_widget_from_xpm_data(slider_sat_colour_xpm);
-	gtk_widget_show(pixmap_w);
-	gtk_box_pack_start(GTK_BOX(vbox), pixmap_w, FALSE, FALSE, 0);
-	label = gtk_label_new("\n");
-	gtk_box_pack_start(GTK_BOX (vbox), label, FALSE, FALSE, 0);
-	gtk_widget_show (label);
-	gtk_box_pack_start(GTK_BOX (hbox), vbox, FALSE, FALSE, 0);
-	gtk_widget_show(vbox);
-
-	return hbox;
+   return hbox;
 }
 
+
 GtkWidget *create_lavrec_layout(GtkWidget *window)
 {
 	GtkWidget *vbox, *hbox, *hbox2, *hbox3, *vbox2, *table;
@@ -895,12 +860,16 @@ GtkWidget *create_lavrec_layout(GtkWidget *window)
 		save_config();
 	}
 
-	hbox3 = create_video_sliders(window);
-	gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, FALSE, 10);
-	gtk_widget_show(hbox3);
+	if (tv)
+ 	{
+		hbox3 = create_video_sliders();
+		gtk_box_pack_start (GTK_BOX (hbox2), hbox3, TRUE, FALSE, 10);
+		gtk_widget_show(hbox3);
+	}
 
 	if (tv == NULL)
 	{
+		//return NULL;
 		tv = gtk_event_box_new();
 		set_background_color(tv, 0,0,0);
 	}
@@ -908,7 +877,7 @@ GtkWidget *create_lavrec_layout(GtkWidget *window)
 	gtk_box_pack_start (GTK_BOX (hbox2), tv, TRUE, FALSE, 10);
 	gtk_widget_show(tv);
 
-	vbox2 = create_audio_sliders(window);
+	vbox2 = create_audio_sliders();
 	gtk_box_pack_start (GTK_BOX (hbox2), vbox2, TRUE, FALSE, 10);
 	gtk_widget_show(vbox2);
 
